| Home | Libraries | People | FAQ | More

### is_list_constructible

    template <class T, class... Args>
    struct is_list_constructible : public true_type-or-false_type {};

Inherits: If `T` can be constructed from `Args` using list initialization (`T{declval<Args>()...}`), then inherits from true_type, otherwise inherits from false_type. `T` must be a complete type.

Compiler Compatibility: This trait requires C++11.

Header: `#include <boost/type_traits/is_list_constructible.hpp>` or `#include <boost/type_traits.hpp>`